@@ -1,21 +1,16 @@
-#!/bin/sh
+#!/bin/bash
 
+. ../utils/tap.sh
 . ./common.sh
 
-log_file="runall.detail.log"
+NUM_TESTS=15
 
-# Check if time bin is non-empty
-if [ -n "$test_time_bin" ]; then
-	time_command="$test_time_bin -a -o $log_file"
-else
-	time_command=""
-fi
+plan_tests	${NUM_TESTS}
 
 for a in test_urcu_gc test_urcu_signal_gc test_urcu_mb_gc test_urcu_qsbr_gc \
 	test_urcu_lgc test_urcu_signal_lgc test_urcu_mb_lgc test_urcu_qsbr_lgc \
 	test_urcu test_urcu_signal test_urcu_mb test_urcu_qsbr \
 	test_rwlock test_perthreadlock test_mutex; do
-	echo "./${a} $*" | tee -a "$log_file"
-	$time_command ./${a} $*
+	okx ${TEST_TIME_BIN} ./"${a}" "$@" 2>"${TMPFILE}"
+	diag "time: $(cat "${TMPFILE}")"
 done
-
