@@ -83,9 +83,10 @@ pthread_mutex_t affinity_mutex = PTHREAD_MUTEX_INITIALIZER;
 
 static void set_affinity(void)
 {
+#if HAVE_SCHED_SETAFFINITY
 	cpu_set_t mask;
-	int cpu;
-	int ret;
+	int cpu, ret;
+#endif /* HAVE_SCHED_SETAFFINITY */
 
 	if (!use_affinity)
 		return;
@@ -283,6 +284,7 @@ int main(int argc, char **argv)
 			   tot_successful_dequeues = 0;
 	unsigned long long end_dequeues = 0;
 	int i, a;
+	unsigned int i_thr;
 
 	if (argc < 4) {
 		show_usage(argc, argv);
@@ -300,7 +302,7 @@ int main(int argc, char **argv)
 		show_usage(argc, argv);
 		return -1;
 	}
-	
+
 	err = sscanf(argv[3], "%lu", &duration);
 	if (err != 1) {
 		show_usage(argc, argv);
@@ -361,15 +363,15 @@ int main(int argc, char **argv)
 
 	next_aff = 0;
 
-	for (i = 0; i < nr_enqueuers; i++) {
-		err = pthread_create(&tid_enqueuer[i], NULL, thr_enqueuer,
-				     &count_enqueuer[2 * i]);
+	for (i_thr = 0; i_thr < nr_enqueuers; i_thr++) {
+		err = pthread_create(&tid_enqueuer[i_thr], NULL, thr_enqueuer,
+				     &count_enqueuer[2 * i_thr]);
 		if (err != 0)
 			exit(1);
 	}
-	for (i = 0; i < nr_dequeuers; i++) {
-		err = pthread_create(&tid_dequeuer[i], NULL, thr_dequeuer,
-				     &count_dequeuer[2 * i]);
+	for (i_thr = 0; i_thr < nr_dequeuers; i_thr++) {
+		err = pthread_create(&tid_dequeuer[i_thr], NULL, thr_dequeuer,
+				     &count_dequeuer[2 * i_thr]);
 		if (err != 0)
 			exit(1);
 	}
@@ -378,7 +380,7 @@ int main(int argc, char **argv)
 
 	test_go = 1;
 
-	for (i = 0; i < duration; i++) {
+	for (i_thr = 0; i_thr < duration; i_thr++) {
 		sleep(1);
 		if (verbose_mode) {
 			fwrite(".", sizeof(char), 1, stdout);
@@ -388,21 +390,21 @@ int main(int argc, char **argv)
 
 	test_stop = 1;
 
-	for (i = 0; i < nr_enqueuers; i++) {
-		err = pthread_join(tid_enqueuer[i], &tret);
+	for (i_thr = 0; i_thr < nr_enqueuers; i_thr++) {
+		err = pthread_join(tid_enqueuer[i_thr], &tret);
 		if (err != 0)
 			exit(1);
-		tot_enqueues += count_enqueuer[2 * i];
-		tot_successful_enqueues += count_enqueuer[2 * i + 1];
+		tot_enqueues += count_enqueuer[2 * i_thr];
+		tot_successful_enqueues += count_enqueuer[2 * i_thr + 1];
 	}
-	for (i = 0; i < nr_dequeuers; i++) {
-		err = pthread_join(tid_dequeuer[i], &tret);
+	for (i_thr = 0; i_thr < nr_dequeuers; i_thr++) {
+		err = pthread_join(tid_dequeuer[i_thr], &tret);
 		if (err != 0)
 			exit(1);
-		tot_dequeues += count_dequeuer[2 * i];
-		tot_successful_dequeues += count_dequeuer[2 * i + 1];
+		tot_dequeues += count_dequeuer[2 * i_thr];
+		tot_successful_dequeues += count_dequeuer[2 * i_thr + 1];
 	}
-	
+
 	test_end(&s, &end_dequeues);
 
 	printf_verbose("total number of enqueues : %llu, dequeues %llu\n",
